<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Gestionnaire des utilisateurs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Ajouter un nouvel utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Ajouter un compte utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Reenter password for new user</source>
        <translation>Re saisissez le mot de passe du nouvel utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>confirm password</source>
        <translation>confirmer le mot de passe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <source>Username of new user</source>
        <translation>Nom du compte du nouvel utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>User login name:</source>
        <translation>Identifiant du nouvel utilisateur :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <location filename="../mainwindow.ui" line="416"/>
        <location filename="../mainwindow.ui" line="1134"/>
        <source>Enter username of new user</source>
        <translation>Entrez le nom du compte du nouvel utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <location filename="../mainwindow.ui" line="422"/>
        <source>username</source>
        <translation>nom d&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="189"/>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Password for new user</source>
        <translation>Mot de passe du nouvel utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="192"/>
        <source>User password:</source>
        <translation>Mot de passe utilisateur :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="205"/>
        <source>Enter password for new user</source>
        <translation>Entrez le mot de passe du nouvel utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <source>password</source>
        <translation>mot de passe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>Confirm user password:</source>
        <translation>Confirmer le mot de passe utilisateur :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Delete User Account</source>
        <translation>Effacer un compte utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>Select user</source>
        <translation>Choisir l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.ui" line="1222"/>
        <location filename="../mainwindow.ui" line="1346"/>
        <location filename="../mainwindow.ui" line="1368"/>
        <source>Select user to delete</source>
        <translation>Sélectionner l&apos;utilisateur à supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>User to delete:</source>
        <translation>Utilisateur à supprimer:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Supprimer également le dossier personnel de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Delete user home directory</source>
        <translation>Supprimer le répertoire home de l&apos;utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Rename User Account</source>
        <translation>Renommer un compte utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="371"/>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Select user to modify:</source>
        <translation>Sélectionner l&apos;utilisateur à modifier :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="403"/>
        <source>New user name:</source>
        <translation>Nouveau nom d&apos;utilisateur : </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <source>Change User Password</source>
        <translation>Changer le mot de passe utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>new password</source>
        <translation>Nouveau mot de passe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>Confirm new password:</source>
        <translation>Confirmer le nouveau mot de passe:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>confirm new password</source>
        <translation>confirmer le nouveau mot de passe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="496"/>
        <source>New user password:</source>
        <translation>Nouveau mot de passe utilisateur:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="527"/>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="530"/>
        <source>Repair a user configuration</source>
        <translation>Réparer une configuration utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="1271"/>
        <source>Modify User Account</source>
        <translation>Modifier le Compte Utilisateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="592"/>
        <source>Select user to repair</source>
        <translation>Sélectionner l&apos;utilisateur devant être modifié</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="579"/>
        <location filename="../mainwindow.ui" line="1355"/>
        <source>User to change:</source>
        <translation>Utilisateur devant être modifié:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="624"/>
        <source>Restore Defaults</source>
        <translation>Rétablir la configuration d&apos;origine</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Rétablir la configuration des navigateurs par défaut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="651"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Configuration de Mozilla (Iceweasel ou Firefox) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="654"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="661"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Rétablir les appartenances à un groupe par défaut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="667"/>
        <source>Group memberships</source>
        <translation>Groupes d&apos;utilisateurs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="680"/>
        <source>Change Autologin Settings</source>
        <translation>Modifier les paramètres de la connexion automatique</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>Log in automatically</source>
        <translation>Se connecter automatiquement</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="693"/>
        <source>Require password to log in</source>
        <translation>Mot de passe requis pour se connecter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="708"/>
        <source>Copy/Sync</source>
        <translation>Copie/Synchronisation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="735"/>
        <source>Copy Between Desktops</source>
        <translation>Copie Entre Bureaux</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="762"/>
        <location filename="../mainwindow.ui" line="829"/>
        <source>Select desktop to copy from</source>
        <translation>Sélectionner le bureau à copier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="775"/>
        <source>Select to only copy files</source>
        <translation>Sélectionner pour uniquement copier les fichiers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="778"/>
        <source>Copy only</source>
        <translation>Copie seule</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="794"/>
        <location filename="../mainwindow.ui" line="807"/>
        <source>Select desktop to copy to</source>
        <translation>Sélectionner le bureau de destination</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="816"/>
        <source>Copy to:</source>
        <translation>Copier vers :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Copy from:</source>
        <translation>Copier :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="851"/>
        <source>Select to copy and then delete differences</source>
        <translation>Sélectionner pour copier puis supprimer les différences</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="854"/>
        <source>Sync</source>
        <translation>Synchroniser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select to copy/sync Shared</source>
        <translation>Sélectionner pour copier/synchroniser le Répertoire Partagé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="903"/>
        <source>Shared folder</source>
        <translation>Répertoire Partagé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="916"/>
        <source>Select to copy/sync entire home</source>
        <translation>Sélectionner pour copier/synchroniser le répertoire home en entier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Entire home</source>
        <translation>Home en entier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="935"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Sélectionner pour copier/synchroniser la configuration du navigateur</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="938"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Configuration de Mozilla (Firefox ou Iceweasel) </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="951"/>
        <source>Select to copy/sync Documents</source>
        <translation>Sélectionner pour copier/synchroniser le répertoire Documents</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Documents folder</source>
        <translation>Répertoire Documents</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="961"/>
        <source>What to copy/sync:</source>
        <translation>Que faut-il copier/synchoniser :</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="977"/>
        <source>Progress</source>
        <translation>Avancement</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1007"/>
        <location filename="../mainwindow.ui" line="1023"/>
        <source>Status of the changes</source>
        <translation>État des modifications</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1026"/>
        <source>Status:</source>
        <translation>État:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1042"/>
        <source>Progress of the changes</source>
        <translation>Niveau d&apos;avancement des modifications</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1079"/>
        <source>Add/Remove Groups</source>
        <translation>Ajouter/Supprimer Groupes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1091"/>
        <source>Add Group</source>
        <translation>Ajouter un Groupe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1121"/>
        <source>Group name:</source>
        <translation>Nom du Groupe:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1140"/>
        <source>groupname</source>
        <translation>nomdugroupe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1169"/>
        <source>Delete Group</source>
        <translation>Supprimer un Groupe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1231"/>
        <source>Group to delete:</source>
        <translation>Groupe à supprimer:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Group Membership</source>
        <translation>Appartenance à un Groupe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1375"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Groupes auxquels l&apos;utilisateur appartient (changer les groupes en cochant/décochant les cases appropriées):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1395"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
        <translation>* Veuillez vérifier attentivement vos sélections avant d&apos;appliquer, car attribuer des adhésions de groupe de manière incorrecte peut casser votre système. En cas d&apos;erreur, utilisez l&apos;onglet de réparation pour restaurer les appartenances d&apos;origine .</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Apply any changes</source>
        <translation>Appliquer les changements</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1458"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1465"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1472"/>
        <source>Cancel any changes then quit</source>
        <translation>Annuler toutes les modifications puis sortir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1475"/>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1523"/>
        <source>Display help </source>
        <translation>Afficher l&apos;aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1526"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1533"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1540"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1543"/>
        <source>About...</source>
        <translation>À propos...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1550"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="112"/>
        <location filename="../mainwindow.cpp" line="174"/>
        <location filename="../mainwindow.cpp" line="182"/>
        <location filename="../mainwindow.cpp" line="197"/>
        <location filename="../mainwindow.cpp" line="219"/>
        <location filename="../mainwindow.cpp" line="242"/>
        <location filename="../mainwindow.cpp" line="250"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="690"/>
        <location filename="../mainwindow.cpp" line="718"/>
        <location filename="../mainwindow.cpp" line="726"/>
        <location filename="../mainwindow.cpp" line="916"/>
        <location filename="../mainwindow.cpp" line="1029"/>
        <source>none</source>
        <translation>aucune</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>La configuration de l&apos;utilisateur va être modifiée. Veuillez fermer toutes les applications ouvertes. Après exécution, veuillez fermer votre session ou redémarrer votre machine. Êtes-vous sûr(e) de vouloir modifier cette configuration maintenant?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <location filename="../mainwindow.cpp" line="312"/>
        <location filename="../mainwindow.cpp" line="439"/>
        <location filename="../mainwindow.cpp" line="494"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Autologin options</source>
        <translation>Options de connexion automatique</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>La connexion automatique a été désactivée pour le compte &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>La connexion automatique a été activée pour le compte &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="307"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Vous devez spécifier une destination pour &quot;copier vers&quot;. Vous ne pouvez pas copier vers le bureau auquel vous êtes connecté.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Avant de débuter la copie, veuillez fermer toutes les applications ouvertes. Assurez-vous que le répertoire de destination a une taille suffisante pour contenir les fichiers que vous désirez copier. Le processus peut effacer ou écraser vos fichiers ou configurations du bureau de destination. Êtes-vous certain(e) de vouloir continuer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="336"/>
        <source>Synchronizing desktop...</source>
        <translation>Synchronisation des bureaux...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Copying desktop...</source>
        <translation>Copie des bureaux...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Le nom d&apos;utilisateur doit comporter au moins 2 caractères. Veuillez choisir un nom d&apos;utilisateur plus long avant de continuer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="552"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Le nom d&apos;utilisateur doit être en minuscules et il
ne peut contenir ni caractères spéciaux ni espaces.
Veuillez choisir un autre nom avant de poursuivre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Désolé, ce nom est déjà attribué. Veuillez choisir un nom différent.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <location filename="../mainwindow.cpp" line="409"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Les mots de passe entrés ne correspondent pas. Veuillez réessayer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="379"/>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Le mot de passe doit contenir au moins 2 caractères. Veuillez entrer un mot de passe plus long avant de poursuivre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="396"/>
        <source>The user was added ok.</source>
        <translation>L&apos;utilisateur a été ajouté avec succès.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Failed to add the user.</source>
        <translation>Ajout de l&apos;utilisateur impossible.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Password successfully changed.</source>
        <translation>Mot de passe modifié avec succès</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Failed to change password.</source>
        <translation>La modification du mot de passe a échoué</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer l&apos;utilisateur %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>The user has been deleted.</source>
        <translation>L&apos;utilisateur a été supprimé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Failed to delete the user.</source>
        <translation>Impossible de supprimer l&apos;utilisateur.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="466"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Le nom du groupe doit être d&apos;au moins 2 caractères. Veuillez sélectionner un nom plus long avant de poursuivre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Le nom du groupe doit être en minuscules et il
ne peut contenir ni caractères spéciaux ni espaces.
Veuillez choisir un autre nom avant de poursuivre.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Désolé, ce nom de Groupe est déjà utilisé. Veuillez choisir un nom différent.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="486"/>
        <source>The system group was added ok.</source>
        <translation>Le groupe du système a bien été ajouté.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <source>Failed to add the system group.</source>
        <translation>Impossible d&apos;ajouter le groupe du système.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Cette action est irréversible. Êtes-vous sûr(e) de vouloir supprimer le groupe %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="499"/>
        <source>The group has been deleted.</source>
        <translation>Le groupe a été supprimé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Failed to delete the group.</source>
        <translation>Impossible de supprimer le groupe.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>The changes have been applied.</source>
        <translation>Les modifications ont été appliquées.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Failed to apply group changes</source>
        <translation>Impossible d&apos;appliquer les changements au groupe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>The selected user name is currently in use.</source>
        <translation>Le nom d&apos;utilisateur choisi est déjà attribué.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Pour modifier le nom de cet utilisateur, déconnectez- vous puis reconnectez-vous sous un autre compte.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="561"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Désolé, ce nom est déjà attribué sur votre système. Veuillez choisir un nom différent.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Échec lors du renommage. Assurez-vous que l&apos;utilisateur ne soit pas connecté. Vous devrez peut-être redémarrer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>The user was renamed.</source>
        <translation>Le nom de l&apos;utilisateur a été changé.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="595"/>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Synchronisation des bureaux...réussie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="597"/>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Copying desktop...ok</source>
        <translation>Copie des bureaux...réussie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Synchronisation des bureaux...échec</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Copying desktop...failed</source>
        <translation>Copie des bureaux...échec</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="669"/>
        <location filename="../mainwindow.cpp" line="968"/>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>browse...</source>
        <translation>Navigation...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="853"/>
        <source>About MX User Manager</source>
        <translation>À propos de MX Gestionnaire des utilisateurs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="854"/>
        <source>MX User Manager</source>
        <translation>MX Gestionnaire des utilisateurs</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="856"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Configuration simple des utilisateurs pour MX Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="857"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="858"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="859"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="860"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="876"/>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>Select folder to copy to</source>
        <translation>Sélectionner le répertoire de destination</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>You must run this program as root.</source>
        <translation>Vous devez lancer cette application avec les droits administrateur.</translation>
    </message>
</context>
</TS>
